<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_content
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

JHtml::_('behavior.tabstate');
JHtml::_('behavior.keepalive');
JHtml::_('behavior.calendar');
JHtml::_('behavior.formvalidator');
JHtml::_('formbehavior.chosen', 'select');
JHtml::_('behavior.modal', 'a.modal_jform_contenthistory');

// Create shortcut to parameters.
$params = $this->state->get('params');
//$images = json_decode($this->item->images);
//$urls = json_decode($this->item->urls);
$app = JFactory::getApplication();

// This checks if the editor config options have ever been saved. If they haven't they will fall back to the original settings.
$editoroptions = isset($params->show_publishing_options);
if (!$editoroptions)
{
	$params->show_urls_images_frontend = '0';
}

JFactory::getDocument()->addScriptDeclaration("
	Joomla.submitbutton = function(task)
	{
		if (task == 'article.cancel' || document.formvalidator.isValid(document.getElementById('adminForm')))
		{
			" . $this->form->getField('articletext')->save() . "
			Joomla.submitform(task);
		}
	}
");
?>
<div class="edit item-page<?php echo $this->pageclass_sfx; ?>">
	<?php if ($params->get('show_page_heading', 1)) : ?>
	<div class="page-header">
		<h1>
			<?php echo $this->escape($params->get('page_heading')); ?>
		</h1>
	</div>
	<?php endif; ?>

	<form action="<?php echo JRoute::_('index.php?option=com_content&a_id=' . (int) $this->item->id); ?>" method="post" name="adminForm" id="adminForm" class="form-validate form-vertical">
		<div class="btn-toolbar">
			<div class="btn-group">
				<button type="button" class="btn btn-default btn-primary" onclick="Joomla.submitbutton('article.save')">
					<span class="glyphicon glyphicon-ok"></span><?php echo JText::_('JSAVE') ?>
				</button>
			</div>
			<div class="btn-group">
				<button type="button" class="btn btn-default" onclick="Joomla.submitbutton('article.cancel')">
					<span class="glyphicon glyphicon-cancel"></span><?php echo JText::_('JCANCEL') ?>
				</button>
			</div>
			<?php if ($params->get('save_history', 0)) : ?>
			<div class="btn-group">
				<?php echo $this->form->getInput('contenthistory'); ?>
			</div>
			<?php endif; ?>
		</div>
		<fieldset>
			<?php 
				$fieldSets = $this->form->getFieldsets();
				$ignoreFieldsets = $this->get('ignore_fieldsets') ?: array();
				$ignoreFields    = $this->get('ignore_fields') ?: array();
				$extraFields     = $this->get('extra_fields') ?: array();
				$tabName         = $this->get('tab_name') ?: 'myTab';
				// These are required to preserve data on save when fields are not displayed.
				$hiddenFieldsets = $this->get('hiddenFieldsets') ?: array();

				// These are required to configure showing and hiding fields in the editor.
				$configFieldsets = $this->get('configFieldsets') ?: array();
				
				// Handle the hidden fieldsets when show_options is set false
				if (!$this->get('show_options', 1))
				{
					// The HTML buffer
					$html   = array();

					// Hide the whole buffer
					$html[] = '<div style="display:none;">';

					// Loop over the fieldsets
					foreach ($fieldSets as $name => $fieldSet)
					{
						// Check if the fieldset should be ignored
						if (in_array($name, $ignoreFieldsets, true))
						{
							continue;
						}

						// If it is a hidden fieldset, render the inputs
						if (in_array($name, $hiddenFieldsets))
						{
							// Loop over the fields
							foreach ($this->form->getFieldset($name) as $field)
							{
								// Add only the input on the buffer
								$html[] = $field->input;
							}

							// Make sure the fieldset is not rendered twice
							$ignoreFieldsets[] = $name;
						}

						// Check if it is the correct fieldset to ignore
						if (strpos($name, 'basic') === 0)
						{
							// Ignore only the fieldsets which are defined by the options not the custom fields ones
							$ignoreFieldsets[] = $name;
						}
					}

					// Close the container
					$html[] = '</div>';

					// Echo the hidden fieldsets
					echo implode('', $html);
				}
			?>
			<ul class="nav nav-tabs">
				<li class="active"><a href="#editor" data-toggle="tab"><?php echo JText::_('COM_CONTENT_ARTICLE_CONTENT') ?></a></li>
				<?php if ($params->get('show_urls_images_frontend') ) : ?>
				<li><a href="#images" data-toggle="tab"><?php echo JText::_('COM_CONTENT_IMAGES_AND_URLS') ?></a></li>
				<?php endif; ?>
				<li><a href="#publishing" data-toggle="tab"><?php echo JText::_('COM_CONTENT_PUBLISHING') ?></a></li>
				<li><a href="#language" data-toggle="tab"><?php echo JText::_('JFIELD_LANGUAGE_LABEL') ?></a></li>
				<li><a href="#metadata" data-toggle="tab"><?php echo JText::_('COM_CONTENT_METADATA') ?></a></li>
				<?php
					foreach ($fieldSets as $name => $fieldSet)
					{
						// Ensure any fieldsets we don't want to show are skipped (including repeating formfield fieldsets)
						if ((isset($fieldSet->repeat) && $fieldSet->repeat === true)
							|| in_array($name, $ignoreFieldsets)
							|| (!empty($configFieldsets) && in_array($name, $configFieldsets, true))
							|| (!empty($hiddenFieldsets) && in_array($name, $hiddenFieldsets, true))
							|| (in_array($name, array("image-intro", "image-full", "jmetadata")))
						)
						{
							continue;
						}
						
						// Determine the label
						if (!empty($fieldSet->label))
						{
							$label = JText::_($fieldSet->label);
						}
						else
						{
							$label = strtoupper('JGLOBAL_FIELDSET_' . $name);
							if (JText::_($label) === $label)
							{
								$label = strtoupper($app->input->get('option') . '_' . $name . '_FIELDSET_LABEL');
							}
							$label = JText::_($label);
						}
						
						echo '<li><a href="#'.$name.'" data-toggle="tab">'.$label.'</a></li>';
					}
				?>
			</ul>

			<div class="tab-content">
				<div class="tab-pane active" id="editor">
					<?php echo $this->form->renderField('title'); ?>

					<?php if (is_null($this->item->id)) : ?>
						<?php echo $this->form->renderField('alias'); ?>
					<?php endif; ?>

					<?php echo $this->form->getInput('articletext'); ?>
				</div>
				<?php if ($params->get('show_urls_images_frontend')): ?>
				<div class="tab-pane" id="images">
					<?php echo $this->form->renderField('image_intro', 'images'); ?>
					<?php echo $this->form->renderField('image_intro_alt', 'images'); ?>
					<?php echo $this->form->renderField('image_intro_caption', 'images'); ?>
					<?php echo $this->form->renderField('float_intro', 'images'); ?>
					<?php echo $this->form->renderField('image_fulltext', 'images'); ?>
					<?php echo $this->form->renderField('image_fulltext_alt', 'images'); ?>
					<?php echo $this->form->renderField('image_fulltext_caption', 'images'); ?>
					<?php echo $this->form->renderField('float_fulltext', 'images'); ?>
					<?php echo $this->form->renderField('urla', 'urls'); ?>
					<?php echo $this->form->renderField('urlatext', 'urls'); ?>
					<div class="form-group">
						<div class="controls">
							<?php echo $this->form->getInput('targeta', 'urls'); ?>
						</div>
					</div>
					<?php echo $this->form->renderField('urlb', 'urls'); ?>
					<?php echo $this->form->renderField('urlbtext', 'urls'); ?>
					<div class="form-group">
						<div class="controls">
							<?php echo $this->form->getInput('targetb', 'urls'); ?>
						</div>
					</div>
					<?php echo $this->form->renderField('urlc', 'urls'); ?>
					<?php echo $this->form->renderField('urlctext', 'urls'); ?>
					<div class="form-group">
						<div class="controls">
							<?php echo $this->form->getInput('targetc', 'urls'); ?>
						</div>
					</div>
				</div>
				<?php endif; ?>
				<div class="tab-pane" id="publishing">
					<?php echo $this->form->renderField('catid'); ?>
					<?php echo $this->form->renderField('tags'); ?>
					<?php if ($params->get('save_history', 0)) : ?>
						<?php echo $this->form->renderField('version_note'); ?>
					<?php endif; ?>
					<?php echo $this->form->renderField('created_by_alias'); ?>
					<?php if ($this->item->params->get('access-change')) : ?>
						<?php echo $this->form->renderField('state'); ?>
						<?php echo $this->form->renderField('featured'); ?>
						<?php echo $this->form->renderField('publish_up'); ?>
						<?php echo $this->form->renderField('publish_down'); ?>
					<?php endif; ?>
					<?php echo $this->form->renderField('access'); ?>
					<?php if (is_null($this->item->id)):?>
						<div class="form-group">
							<div class="control-label">
							</div>
							<div class="controls">
								<?php echo JText::_('COM_CONTENT_ORDERING'); ?>
							</div>
						</div>
					<?php endif; ?>
				</div>
				<div class="tab-pane" id="language">
					<?php echo $this->form->renderField('language'); ?>
				</div>
				<div class="tab-pane" id="metadata">
					<?php echo $this->form->renderField('metadesc'); ?>
					<?php echo $this->form->renderField('metakey'); ?>

					<input type="hidden" name="task" value="" />
					<input type="hidden" name="return" value="<?php echo $this->return_page; ?>" />
					<?php if ($this->params->get('enable_category', 0) == 1) :?>
					<input type="hidden" name="jform[catid]" value="<?php echo $this->params->get('catid', 1); ?>" />
					<?php endif; ?>
				</div>
				<?php
					foreach ($fieldSets as $name => $fieldSet)
					{
						// Ensure any fieldsets we don't want to show are skipped (including repeating formfield fieldsets)
						if ((isset($fieldSet->repeat) && $fieldSet->repeat === true)
							|| in_array($name, $ignoreFieldsets)
							|| (!empty($configFieldsets) && in_array($name, $configFieldsets, true))
							|| (!empty($hiddenFieldsets) && in_array($name, $hiddenFieldsets, true))
							|| (in_array($name, array("image-intro", "image-full", "jmetadata")))
						)
						{
							continue;
						}
						
						// The name of the fieldset to render
						$this->fieldset = $name;

						// Force to show the options
						$this->showOptions = true;

						// Render the fieldset
						echo '<div class="tab-pane" id="'.$name.'">'.JLayoutHelper::render('joomla.edit.fieldset', $this)."</div>";
					}
				?>
			</div>
			<?php echo JHtml::_('form.token'); ?>
		</fieldset>
	</form>
</div>
<script>
// MooTools
window.addEvent('domready',function() {
	Element.prototype.hide = function() {
	// Do nothing
	};
});
</script>
